@@ -1,20 +1,21 @@
-calculatecentroid <- function(beta){
-    n = nrow(beta)
-    T1 = ncol(beta)
 
-    betadot = apply(beta,1,gradient,1.0/(T1-1))
-    betadot = t(betadot)
-
-    normbetadot = apply(betadot,2,pvecnorm,2)
-    integrand = matrix(0, n, T1)
-    for (i in 1:T1){
-        integrand[,i] = beta[,i] * normbetadot[i]
-    }
-
-    scale = trapz(seq(0,1,length.out=T1), normbetadot)
-    centroid = trapz(seq(0,1,length.out=T1), integrand, 2)/scale
-
-    return(centroid)
+calculatecentroid <- function(beta,returnlength = F){
+  n = nrow(beta)
+  T1 = ncol(beta)
+  
+  betadot = apply(beta,1,gradient,1.0/(T1-1))
+  betadot = t(betadot)
+  
+  normbetadot = apply(betadot,2,pvecnorm,2)
+  integrand = matrix(0, n, T1)
+  for (i in 1:T1){
+    integrand[,i] = beta[,i] * normbetadot[i]
+  }
+  
+  scale = trapz(seq(0,1,length.out=T1), normbetadot)
+  centroid = apply(integrand,1,trapz,x = seq(0,1,length.out=T1))/scale
+  if(returnlength)  return(list("length" = scale,"centroid" = centroid))
+  return(centroid)
 }
 
 
