@@ -16,8 +16,8 @@
 #' @references Srivastava, A., Klassen, E., Joshi, S., Jermyn, I., (2011). Shape analysis of elastic curves in euclidean spaces. Pattern Analysis and Machine Intelligence, IEEE Transactions on 33 (7), 1415-1428.
 #' @export
 #' @examples
-#' out <- curve_srvf_align(beta[, , 1, 1:2], maxit = 2)
-#' # note: use more shapes, small for speed
+#' data("mpeg7")
+#' out = curve_srvf_align(beta[,,1,1:2],maxit=2) # note: use more shapes, small for speed
 curve_srvf_align <- function(beta, mode="O", rotated=T, scale = F, maxit=20, ms = "mean"){
     if (mode=="C"){
       isclosed = TRUE
@@ -35,13 +35,16 @@ curve_srvf_align <- function(beta, mode="O", rotated=T, scale = F, maxit=20, ms
 
     qn = array(0, c(n,T1,N))
     betan = array(0, c(n,T1,N))
-
+    rotmat = array(0, c(n,n,N)) 
+    gams = matrix(0, T1, N)     
+ 
     # align to mean
     for (ii in 1:N){
         q1 = q[,,ii]
         beta1 = beta[,,ii]
 
         out = find_rotation_seed_unqiue(mu,q1,mode)
+        gams[,ii] = out$gambest 
         beta1 = out$Rbest%*%beta1
         beta1n = group_action_by_gamma_coord(beta1, out$gambest)
         q1n = curve_to_q(beta1n)$q
@@ -49,8 +52,7 @@ curve_srvf_align <- function(beta, mode="O", rotated=T, scale = F, maxit=20, ms
         out = find_best_rotation(mu, q1n)
         qn[,,ii] = out$q2new
         betan[,,ii] = out$R%*%beta1n
-
+        rotmat[,,ii] = out$R  
     }
-
-    return(list(betan=betan, qn=qn, betamean=betamean, q_mu=mu))
+    return(list(betan=betan, qn=qn, betamean=betamean, q_mu=mu, rotmat = rotmat,gams = gams,v=v))
 }
