@@ -5,8 +5,8 @@
 #' @param f matrix of N function of M time points (MxN)
 #' @param time sample points of functions
 #' @param lambda controls amount of warping (default = 0)
-#' @param pen alignment penalty (default="roughness") options are 
-#' second derivative ("roughness"), geodesic distance from id ("geodesic"), and 
+#' @param pen alignment penalty (default="roughness") options are
+#' second derivative ("roughness"), geodesic distance from id ("geodesic"), and
 #' norm from id ("norm")
 #' @param parallel run computation in parallel (default = T)
 #' @return Returns a list containing \item{amp}{amplitude depth}
@@ -18,14 +18,14 @@
 #' @examples
 #' depths <- elastic.depth(simu_data$f[, 1:4], simu_data$time)
 elastic.depth <- function(f,time,lambda = 0, pen="roughness", parallel = FALSE){
-    if (parallel){
-        cores = detectCores()-1
-        cl = makeCluster(cores)
-        registerDoParallel(cl)
-    } else
-    {
-        registerDoSEQ()
-    }
+  if (parallel){
+    cores = max(parallel::detectCores() - 1, 1)
+    cl = parallel::makeCluster(cores)
+    doParallel::registerDoParallel(cl)
+  } else
+  {
+    foreach::registerDoSEQ()
+  }
 
     obs = nrow(f)
     fns = ncol(f)
@@ -36,10 +36,10 @@ elastic.depth <- function(f,time,lambda = 0, pen="roughness", parallel = FALSE){
 
     for (f1 in 1:(fns-1)) {
 
-        dist<-foreach(k = f1:ncol(f), .combine=cbind,.packages='fdasrvf') %dopar% {
+        dist<-foreach::foreach(k = f1:ncol(f), .combine=cbind,.packages='fdasrvf') %dopar% {
 
             out = elastic.distance(f[,f1], f[,k], time, lambda, pen)
-            
+
             list(out$Dy,out$Dx)
         }
 
@@ -56,13 +56,11 @@ elastic.depth <- function(f,time,lambda = 0, pen="roughness", parallel = FALSE){
     amp_dist = amp_dist + t(amp_dist)
     phs_dist = phs_dist + t(phs_dist)
 
-    amp = 1 / (1 + apply(amp_dist, 1, median))
-    phase = 1 / (1 + apply(phs_dist, 1, median))
+    amp = 1 / (1 + apply(amp_dist, 1, stats::median))
+    phase = 1 / (1 + apply(phs_dist, 1, stats::median))
     phase = ((2+pi)/pi) * (phase - 2/(2+pi))
 
-    if (parallel){
-        stopCluster(cl)
-    }
+    if (parallel) parallel::stopCluster(cl)
 
     return(list(amp=amp,phase=phase))
 }
